@@ -38,7 +38,7 @@ def install():
         # 当gunicorn模式启动时，gunicorn会自行上报log信息，也会被此插件拦截，故需剔除gunicorn的log上报 eg：<Logger gunicorn.error (INFO)>
         # uwsgi 不需要拦截，因其无错误log调用
         err_log = this.__str__()
-        if "gunicorn" in err_log or "kafka" in err_log:
+        if "gunicorn" in err_log or "kafka" in err_log or "tornado" in err_log:
             res = _handle(this, level, msg, args, exc_info=None, extra=None, stack_info=False, stacklevel=1)
 
             return res
@@ -65,7 +65,7 @@ def install():
         # 当gunicorn模式启动时，gunicorn会自行上报log信息，也会被此插件拦截，故需剔除gunicorn的log上报 eg：<Logger gunicorn.error (INFO)>
         # uwsgi 不需要拦截，因其无错误log调用
         err_log = this.__str__()
-        if "gunicorn" in err_log or "kafka" in err_log:
+        if "gunicorn" in err_log or "kafka" in err_log or "tornado" in err_log:
             res = _handle(this, level, msg, args, exc_info=None, extra=None, stack_info=False)
 
             return res
